@@ -123,8 +123,13 @@ static void window_closed_cb(WnckScreen *screen, WnckWindow *window)
 void init_screens()
 {
 	int i;
-	const int num_screens =
-		gdk_display_get_n_screens(gdk_display_get_default());
+	int num_screens;
+
+#ifndef GDK_VERSION_3_10
+	num_screens = gdk_display_get_n_screens(gdk_display_get_default());
+#else
+	num_screens = 1;
+#endif
 
 	for (i=0; i<num_screens; i++) {
 		WnckScreen *screen = wnck_screen_get(i);
@@ -243,6 +248,7 @@ void folder_changed_callback(GFileMonitor *mon,
 
 		clear_file_lists();
 
+		set_current_window(NULL);
 		load_config(our_filename);
 
 		if (debug)
@@ -264,6 +270,7 @@ void folder_changed_callback(GFileMonitor *mon,
 
 				clear_file_lists();
 
+				set_current_window(NULL);
 				load_config(our_filename);
 
 				print_script_lists();
@@ -316,8 +323,8 @@ int main(int argc, char *argv[])
 
 	gchar *full_desc_string = g_strdup_printf("- %s", devilspie2_description);
 
-	context=g_option_context_new(full_desc_string);
-	g_option_context_add_main_entries(context,options,NULL);
+	context = g_option_context_new(full_desc_string);
+	g_option_context_add_main_entries(context,options, NULL);
 	if (!g_option_context_parse(context, &argc, &argv, &error)) {
 		g_print(_("option parsing failed: %s"), error->message);
 		printf("\n");
@@ -380,6 +387,10 @@ int main(int argc, char *argv[])
 		exit(EXIT_FAILURE);
 	}
 
+	// set the current window to NULL, we don't need to be able to modify
+	// the windows when reading the config
+	set_current_window(NULL);
+
 	config_filename =
 		g_build_filename(script_folder, "devilspie2.lua", NULL);
 
