@@ -1,6 +1,6 @@
 /**
  *	This file is part of devilspie2
- *	Copyright (C) 2011-2013 Andreas Rönnquist
+ *	Copyright (C) 2011-2014 Andreas Rönnquist
  *
  *	devilspie2 is free software: you can redistribute it and/or
  *	modify it under the terms of the GNU General Public License as published
@@ -34,6 +34,8 @@ int c_set_window_geometry2(lua_State *lua);
 
 int c_set_window_size(lua_State *lua);
 
+int c_set_window_strut(lua_State *lua);
+
 int c_make_always_on_top(lua_State *lua);
 
 int c_set_on_top(lua_State *lua);
@@ -110,4 +112,9 @@ int c_get_screen_geometry(lua_State *lua);
 
 int c_focus(lua_State *lua);
 
+int c_get_window_fullscreen(lua_State *lua);
+
+int c_xy(lua_State *lua);
+int c_xywh(lua_State *lua);
+
 #endif /*__HEADER_SCRIPT_FUNCTIONS_*/
