@@ -1,6 +1,6 @@
 /**
  *	This file is part of devilspie2
- *	Copyright (C) 2001 Havoc Pennington, 2011-2013 Andreas Rönnquist
+ *	Copyright (C) 2001 Havoc Pennington, 2011-2014 Andreas Rönnquist
  *
  *	devilspie2 is free software: you can redistribute it and/or
  *	modify it under the terms of the GNU General Public License as published
@@ -24,6 +24,9 @@
 #include <X11/Xlib.h>
 #include <string.h>
 
+#define WNCK_I_KNOW_THIS_IS_UNSTABLE
+#include <libwnck/libwnck.h>
+
 #include <locale.h>
 
 #include <libintl.h>
@@ -310,19 +313,19 @@ my_wnck_get_cardinal_list (Window xwindow, Atom atom,
 	gulong *nums;
 	int err, result;
 
-	*cardinals=NULL;
-	*len=0;
+	*cardinals = NULL;
+	*len = 0;
 
 	devilspie2_error_trap_push();
-	type=None;
-	result=XGetWindowProperty(gdk_x11_get_default_xdisplay (),
+	type = None;
+	result = XGetWindowProperty(gdk_x11_get_default_xdisplay (),
 	                             xwindow,
 	                             atom,
 	                             0, G_MAXLONG,
 	                             False, XA_CARDINAL, &type, &format, &nitems,
 	                             &bytes_after, (void*)&nums);
 
-	err=devilspie2_error_trap_pop();
+	err = devilspie2_error_trap_pop();
 
 	if ((err!=Success) || (result!=Success))
 		return FALSE;
@@ -332,9 +335,9 @@ my_wnck_get_cardinal_list (Window xwindow, Atom atom,
 		return FALSE;
 	}
 
-	*cardinals=g_new(gulong, nitems);
+	*cardinals = g_new(gulong, nitems);
 	memcpy(*cardinals, nums, sizeof (gulong) * nitems);
-	*len=nitems;
+	*len = nitems;
 
 	XFree(nums);
 
@@ -350,14 +353,14 @@ int devilspie2_get_viewport_start(Window xid)
 	gulong *list;
 	int len;
 
-	int result=-1;
+	int result = -1;
 
 	my_wnck_get_cardinal_list(RootWindowOfScreen(
 										devilspie2_window_get_xscreen(xid)),
 										my_wnck_atom_get("_NET_DESKTOP_VIEWPORT"),
 										&list, &len);
 
-	if (len>0) result=list[0];
+	if (len>0) result = list[0];
 
 	g_free(list);
 
@@ -417,7 +420,7 @@ void my_window_set_window_type(Window xid, gchar *window_type)
 		type = g_strdup(window_type);
 	}
 
-	atoms[0]=XInternAtom(display, type, False);
+	atoms[0] = XInternAtom(display, type, False);
 
 	XChangeProperty(gdk_x11_get_default_xdisplay(), xid,
 						XInternAtom(display, "_NET_WM_WINDOW_TYPE", False), XA_ATOM, 32,
@@ -443,3 +446,40 @@ void my_window_set_opacity(Window xid, double value)
 						PropModeReplace, (unsigned char *) &opacity, 1L);
 
 }
+
+
+/**
+ *
+ */
+void set_window_geometry(WnckWindow *window, int x, int y, int w, int h)
+{
+
+	if (window) {
+		WnckScreen *screen = wnck_window_get_screen(window);
+		int sw = wnck_screen_get_width(screen);
+		int sh = wnck_screen_get_height(screen);
+
+		int gravity = WNCK_WINDOW_GRAVITY_CURRENT;
+		if (x >= 0 && y >= 0)
+			gravity = WNCK_WINDOW_GRAVITY_NORTHWEST;
+		if (x >= 0 && y < 0)
+			gravity = WNCK_WINDOW_GRAVITY_SOUTHWEST;
+		if (x < 0 && y >= 0)
+			gravity = WNCK_WINDOW_GRAVITY_NORTHEAST;
+		if (x < 0 && y < 0)
+			gravity = WNCK_WINDOW_GRAVITY_SOUTHEAST;
+		if (x < 0)
+			x = sw + x;
+		if (y < 0)
+			y = sh + y;
+
+		wnck_window_set_geometry(window,
+										 gravity,
+										 WNCK_WINDOW_CHANGE_X +
+										 WNCK_WINDOW_CHANGE_Y +
+										 WNCK_WINDOW_CHANGE_WIDTH +
+										 WNCK_WINDOW_CHANGE_HEIGHT,
+										 x, y, w, h);
+	}
+
+}
